summaryrefslogtreecommitdiff
path: root/xmlsecurity/inc
diff options
context:
space:
mode:
authorMiklos Vajna <vmiklos@collabora.co.uk>2016-10-13 21:07:55 +0200
committerMiklos Vajna <vmiklos@collabora.co.uk>2016-10-14 07:05:52 +0000
commite584bc808b634bf18ba5f7538d598e135b28f090 (patch)
treec92ad645b1b068db924b248084eee98788a27b1e /xmlsecurity/inc
parente1118f1b940df9a2504a63823f93b1e609daa97c (diff)
xmlsecurity: extract certificate from PDF signature
So that the UI can show the correct "Signed by" and "Digital ID issued by" fields. Change-Id: Ied2fed480f48baf60cffb4f0ce762a726beab006 Reviewed-on: https://gerrit.libreoffice.org/29776 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Miklos Vajna <vmiklos@collabora.co.uk>
Diffstat (limited to 'xmlsecurity/inc')
-rw-r--r--xmlsecurity/inc/pdfio/pdfdocument.hxx5
-rw-r--r--xmlsecurity/inc/sigstruct.hxx2
2 files changed, 4 insertions, 3 deletions
diff --git a/xmlsecurity/inc/sigstruct.hxx b/xmlsecurity/inc/sigstruct.hxx
index 8650a8f84ac2..610845cb0ae2 100644
--- a/xmlsecurity/inc/sigstruct.hxx
+++ b/xmlsecurity/inc/sigstruct.hxx
@@ -23,7 +23,7 @@
#include <rtl/ustring.hxx>
#include <com/sun/star/util/DateTime.hpp>
#include <com/sun/star/xml/crypto/SecurityOperationStatus.hpp>
-#include <com/sun/star/uno/Sequence.h>
+#include <com/sun/star/uno/Sequence.hxx>
#include <vector>
diff --git a/xmlsecurity/inc/pdfio/pdfdocument.hxx b/xmlsecurity/inc/pdfio/pdfdocument.hxx
index 9d072615b599..79cd7168a364 100644
--- a/xmlsecurity/inc/pdfio/pdfdocument.hxx
+++ b/xmlsecurity/inc/pdfio/pdfdocument.hxx
@@ -16,6 +16,7 @@
#include <tools/stream.hxx>
#include <xmlsecuritydllapi.h>
+#include <sigstruct.hxx>
namespace xmlsecurity
{
@@ -58,8 +59,8 @@ public:
bool Read(SvStream& rStream);
std::vector<PDFObjectElement*> GetSignatureWidgets();
- /// Return value is about if we can determine a result, bDigestMatch is about the actual result.
- static bool ValidateSignature(SvStream& rStream, PDFObjectElement* pSignature, bool& bDigestMatch);
+ /// Return value is about if we can determine a result, rInformation is about the actual result.
+ static bool ValidateSignature(SvStream& rStream, PDFObjectElement* pSignature, SignatureInformation& rInformation);
};
} // namespace pdfio